aboutsummaryrefslogtreecommitdiffstats
path: root/resources/traffic_scripts
diff options
context:
space:
mode:
authorZdeno Olsovsky <zolsovsk@cisco.com>2016-05-04 13:48:36 +0200
committerMatej Klotton <mklotton@cisco.com>2016-05-20 12:09:01 +0000
commitc5e740fbe49b3074647c8c5fc09d26a131cea577 (patch)
tree547475657b740c3d68c1133d2dc69453c9602665 /resources/traffic_scripts
parent1e7afbe3474d8ae8c5239ae3deee49963d6b1d93 (diff)
VPP in host user-mode, part II
- JIRA: CSIT-61 Change-Id: I688b1013a78a1fa3ecdb44c2072f8bd1b46364fb Signed-off-by: Zdeno Olsovsky <zolsovsk@cisco.com>
Diffstat (limited to 'resources/traffic_scripts')
-rwxr-xr-xresources/traffic_scripts/send_ip_icmp.py81
1 files changed, 66 insertions, 15 deletions
diff --git a/resources/traffic_scripts/send_ip_icmp.py b/resources/traffic_scripts/send_ip_icmp.py
index 711bf3dd25..23e647f43c 100755
--- a/resources/traffic_scripts/send_ip_icmp.py
+++ b/resources/traffic_scripts/send_ip_icmp.py
@@ -12,18 +12,57 @@
# See the License for the specific language governing permissions and
# limitations under the License.
-"""Traffic script that sends an ip icmp packet
-from one interface to the other"""
+"""Traffic script that sends an IP ICMPv4/ICMPv6 packet
+from one interface to the other one."""
import sys
-from resources.libraries.python.PacketVerifier import RxQueue, TxQueue
-from resources.libraries.python.TrafficScriptArg import TrafficScriptArg
+import ipaddress
+
from scapy.layers.inet import ICMP, IP
from scapy.all import Ether
+from scapy.layers.inet6 import ICMPv6EchoRequest
+from scapy.layers.inet6 import IPv6
+
+from resources.libraries.python.PacketVerifier import RxQueue, TxQueue
+from resources.libraries.python.TrafficScriptArg import TrafficScriptArg
+
+
+def valid_ipv4(ip):
+ """Check if IP address has the correct IPv4 address format.
+
+ :param ip: IP address.
+ :type ip: str
+ :return: True in case of correct IPv4 address format,
+ otherwise return false.
+ :rtype: bool
+ """
+ try:
+ ipaddress.IPv4Address(unicode(ip))
+ return True
+ except (AttributeError, ipaddress.AddressValueError):
+ return False
+
+
+def valid_ipv6(ip):
+ """Check if IP address has the correct IPv6 address format.
+
+ :param ip: IP address.
+ :type ip: str
+ :return: True in case of correct IPv6 address format,
+ otherwise return false.
+ :rtype: bool
+ """
+ try:
+ ipaddress.IPv6Address(unicode(ip))
+ return True
+ except (AttributeError, ipaddress.AddressValueError):
+ return False
def main():
- """ Send IP icmp packet from one traffic generator interface to the other"""
+ """Send IP ICMPv4/ICMPv6 packet from one traffic generator interface to
+ the other one.
+ """
args = TrafficScriptArg(['src_mac', 'dst_mac', 'src_ip', 'dst_ip'])
src_mac = args.get_arg('src_mac')
@@ -37,11 +76,23 @@ def main():
txq = TxQueue(tx_if)
sent_packets = []
-
+ ip_format = ''
+ icmp_format = ''
# Create empty ip ICMP packet and add padding before sending
- pkt_raw = Ether(src=src_mac, dst=dst_mac) / \
- IP(src=src_ip, dst=dst_ip) / \
- ICMP()
+ if valid_ipv4(src_ip) and valid_ipv4(dst_ip):
+ pkt_raw = (Ether(src=src_mac, dst=dst_mac) /
+ IP(src=src_ip, dst=dst_ip) /
+ ICMP())
+ ip_format = 'IP'
+ icmp_format = 'ICMP'
+ elif valid_ipv6(src_ip) and valid_ipv6(dst_ip):
+ pkt_raw = (Ether(src=src_mac, dst=dst_mac) /
+ IPv6(src=src_ip, dst=dst_ip) /
+ ICMPv6EchoRequest())
+ ip_format = 'IPv6'
+ icmp_format = 'ICMPv6EchoRequest'
+ else:
+ raise ValueError("IP(s) not in correct format")
# Send created packet on one interface and receive on the other
sent_packets.append(pkt_raw)
@@ -53,13 +104,13 @@ def main():
if ether is None:
raise RuntimeError('ICMP echo Rx timeout')
- if not ether.haslayer(IP):
- raise RuntimeError(
- 'Not an IP packet received {0}'.format(ether.__repr__()))
+ if not ether.haslayer(ip_format):
+ raise RuntimeError('Not an IP packet received {0}'
+ .format(ether.__repr__()))
- if not ether.haslayer(ICMP):
- raise RuntimeError(
- 'Not an ICMP packet received {0}'.format(ether.__repr__()))
+ if not ether.haslayer(icmp_format):
+ raise RuntimeError('Not an ICMP packet received {0}'
+ .format(ether.__repr__()))
sys.exit(0)